Class: PageView
- Inherits:
-
ActiveRecord::Base
- Object
- ActiveRecord::Base
- PageView
- Includes:
- E9::ActiveRecord::TimeScopes, E9Rails::ActiveRecord::Scopes::Times
- Defined in:
- app/models/page_view.rb
Overview
A visit to the site
Page views belong to a tracking cookie, from which it derives its campaign code, and whether or not it is a "new visit" for the given campaign code.
Also stored from the request:
[request_path] The full request path [user_agent] The request user agent [referer] The request referer if it exists [remote_ip] The originating ip address of the request [session] The session id of the request